/*
 * jSite-next - InsertListenerSupport.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jsite.core;

import net.pterodactylus.util.event.ListenerSupport;

/**
 * Helper class that fires {@link InsertListener} events.
 *
 * @author David ‘Bombe’ Roden &lt;bombe@freenetproject.org&gt;
 */
public class InsertListenerSupport extends ListenerSupport<InsertListener> {

	/**
	 * Notifies all listeners that the insert was added.
	 *
	 * @see InsertListener#insertAdded(Insert)
	 * @param insert
	 *            The insert that was added
	 */
	public void fireInsertAdded(Insert insert) {
		for (InsertListener insertListener : getListeners()) {
			insertListener.insertAdded(insert);
		}
	}

	/**
	 * Notifies all listeners that the insert was removed.
	 *
	 * @see InsertListener#insertRemoved(Insert)
	 * @param insert
	 *            The insert that was removed
	 */
	public void fireInsertRemoved(Insert insert) {
		for (InsertListener insertListener : getListeners()) {
			insertListener.insertRemoved(insert);
		}
	}

	/**
	 * Notifies all listeners that the insert was started.
	 *
	 * @see InsertListener#insertStarted(Insert)
	 * @param insert
	 *            The insert that was started
	 */
	public void fireInsertStarted(Insert insert) {
		for (InsertListener insertListener : getListeners()) {
			insertListener.insertStarted(insert);
		}
	}

	/**
	 * Notifies all listeners that the insert made progress.
	 *
	 * @see InsertListener#insertProgressed(Insert)
	 * @param insert
	 *            The insert that made progress
	 */
	public void fireInsertProgressed(Insert insert) {
		for (InsertListener insertListener : getListeners()) {
			insertListener.insertProgressed(insert);
		}
	}

	/**
	 * Notifies all listeners that the insert generated a URI.
	 *
	 * @see InsertListener#insertGeneratedURI(Insert, String)
	 * @param insert
	 *            The insert that generated a URI
	 * @param generatedUri
	 *            The URI that was generated
	 */
	public void fireInsertGeneratedURI(Insert insert, String generatedUri) {
		for (InsertListener insertListener : getListeners()) {
			insertListener.insertGeneratedURI(insert, generatedUri);
		}
	}

	/**
	 * Notifies all listeners that the insert has finished.
	 *
	 * @see InsertListener#insertFinished(Insert)
	 * @param insert
	 *            The insert that was finished
	 */
	public void fireInsertFinished(Insert insert) {
		for (InsertListener insertListener : getListeners()) {
			insertListener.insertFinished(insert);
		}
	}

}
